summaryrefslogtreecommitdiff
path: root/maj
diff options
context:
space:
mode:
authorLudovic Pouzenc <ludovic@pouzenc.fr>2017-11-04 17:22:58 +0100
committerLudovic Pouzenc <ludovic@pouzenc.fr>2017-11-04 17:22:58 +0100
commita66d5fa3a144602d529d22623ff129486f285f14 (patch)
treec278fd5f6606adb50a022316f92300dcb0c65e6c /maj
parenta43dc0686985f4e61088d0c8f9d0f92fe26fae93 (diff)
downloadchd_openwrt-a66d5fa3a144602d529d22623ff129486f285f14.zip
chd_openwrt-a66d5fa3a144602d529d22623ff129486f285f14.tar.gz
chd_openwrt-a66d5fa3a144602d529d22623ff129486f285f14.tar.bz2
gen-dev: Fix for 841v11, we need -eu.bin for upgrades. + dev to prod.
Diffstat (limited to 'maj')
-rw-r--r--maj/gen-dev.php8
-rw-r--r--maj/gen.php44
2 files changed, 30 insertions, 22 deletions
diff --git a/maj/gen-dev.php b/maj/gen-dev.php
index 1283bb4..cc08e5d 100644
--- a/maj/gen-dev.php
+++ b/maj/gen-dev.php
@@ -67,6 +67,7 @@ $res &= validate($pattern_int, 'txpower', 'Puissance d\'émission WiFi incorrect
$res &= checksame('pwd1', 'pwd2', 'Les mots de passes ne correspondent pas', $errors);
$res &= checksame('key1', 'key2', 'Les mots de passes ne correspondent pas', $errors);
+$region="";
switch ($_POST['profile']) {
case 'TLWR740':
switch($_POST['revision']) {
@@ -75,7 +76,7 @@ switch ($_POST['profile']) {
break;
case '4':
case '5':
- case '6':
+ /* case '6': # PAS TESTE, on en a pas */
$target="tl-wr740n-v" . $_POST['revision'];
break;
default:
@@ -87,8 +88,11 @@ switch ($_POST['profile']) {
switch($_POST['revision']) {
case '9':
case '10':
+ $target="tl-wr841-v" . $_POST['revision'];
+ break;
case '11':
$target="tl-wr841-v" . $_POST['revision'];
+ $region="-eu";
break;
default:
$errors['revision'] = 'Pas de mise à jour disponible pour l\'instant (' . (isset($_POST['revision'])?$_POST[$index]:'vide') . ')';
@@ -103,7 +107,7 @@ switch ($_POST['profile']) {
$profile="DEVICE_$target";
$user_filename="mise-a-jour-routeur-$target.bin";
-$gen_filename="bin/targets/ar71xx/generic/lede-17.01.2-ar71xx-generic-$target-squashfs-factory.bin";
+$gen_filename="bin/targets/ar71xx/generic/lede-17.01.2-ar71xx-generic-$target-squashfs-factory$region.bin";
if ( !$res ) {
echo "<!DOCTYPE html>\n<html>\n<head>\n<meta charset=\"utf-8\" />\n</head>\n<body>\n<h2>Oops, une erreur s'est produite</h2><div>Il y a un problème avec les renseignements fournis<br><ul>\n";
diff --git a/maj/gen.php b/maj/gen.php
index e2d8486..e6bb308 100644
--- a/maj/gen.php
+++ b/maj/gen.php
@@ -1,19 +1,23 @@
<?php
/**
- * Copyright 2016 Ludovic Pouzenc <ludovic@pouzenc.fr>
+ *
+ * Renamed from "CHD OpenWRT" to "CHD LEDE" on 2017-06-21
+ *
+ * Copyright 2016-2017 Ludovic Pouzenc <ludovic@pouzenc.fr>
+ * Copyright 2017 Nicolas Goaziou <mail@nicolasgoaziou.fr>
*
* CHD OpenWRT is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* CHD OpenWRT is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with CHD OpenWRT. If not, see <http://www.gnu.org/licenses/>.
+ * along with CHD LEDE. If not, see <http://www.gnu.org/licenses/>.
**/
function validate($regex, $index, $message, &$errors) {
@@ -63,24 +67,20 @@ $res &= validate($pattern_int, 'txpower', 'Puissance d\'émission WiFi incorrect
$res &= checksame('pwd1', 'pwd2', 'Les mots de passes ne correspondent pas', $errors);
$res &= checksame('key1', 'key2', 'Les mots de passes ne correspondent pas', $errors);
+$region="";
switch ($_POST['profile']) {
case 'TLWR740':
switch($_POST['revision']) {
case '51':
- $profile='TLWR740';
- $user_filename="mise-a-jour-routeur-TLWR740v5.1.bin";
- $gen_filename="bin/ar71xx/openwrt-ar71xx-generic-tl-wr740n-v5-squashfs-factory.bin";
+ $target="tl-wr740n-v5";
break;
case '4':
case '5':
- case '6':
- $profile='TLWR740';
- $revision=$_POST['revision'];
- $user_filename="mise-a-jour-routeur-TLWR740v$revision.bin";
- $gen_filename="bin/ar71xx/openwrt-ar71xx-generic-tl-wr740n-v$revision-squashfs-factory.bin";
+ /* case '6': # PAS TESTE, on en a pas */
+ $target="tl-wr740n-v" . $_POST['revision'];
break;
default:
- $errors['revision'] = 'Routeur non supporté (' . (isset($_POST['revision'])?$_POST[$index]:'vide') . ')';
+ $errors['revision'] = 'Pas de mise à jour disponible pour l\'instant (' . (isset($_POST['revision'])?$_POST[$index]:'vide') . ')';
$res = false;
}
break;
@@ -88,23 +88,27 @@ switch ($_POST['profile']) {
switch($_POST['revision']) {
case '9':
case '10':
-/* case '11': XXX un 841n V11.1 a été briqué le 07/06/2017, à investiguer */
- $profile='TLWR841';
- $revision=$_POST['revision'];
- $user_filename="mise-a-jour-routeur-TLWR841v$revision.bin";
- $gen_filename="bin/ar71xx/openwrt-ar71xx-generic-tl-wr841n-v$revision-squashfs-factory.bin";
+ $target="tl-wr841-v" . $_POST['revision'];
+ break;
+ case '11':
+ $target="tl-wr841-v" . $_POST['revision'];
+ $region="-eu";
break;
default:
- $errors['revision'] = 'Routeur non supporté (' . (isset($_POST['revision'])?$_POST[$index]:'vide') . ')';
+ $errors['revision'] = 'Pas de mise à jour disponible pour l\'instant (' . (isset($_POST['revision'])?$_POST[$index]:'vide') . ')';
$res = false;
}
break;
default:
- $errors['profile'] = 'Routeur non supporté (' . (isset($_POST[$index])?$_POST['profile']:'vide') . ')';
+ $errors['profile'] = 'Pas de mise à jour disponible pour l\'instant (' . (isset($_POST[$index])?$_POST['profile']:'vide') . ')';
$res = false;
}
+$profile="DEVICE_$target";
+$user_filename="mise-a-jour-routeur-$target.bin";
+$gen_filename="bin/targets/ar71xx/generic/lede-17.01.2-ar71xx-generic-$target-squashfs-factory$region.bin";
+
if ( !$res ) {
echo "<!DOCTYPE html>\n<html>\n<head>\n<meta charset=\"utf-8\" />\n</head>\n<body>\n<h2>Oops, une erreur s'est produite</h2><div>Il y a un problème avec les renseignements fournis<br><ul>\n";
foreach ($errors as $k=>$v) {
@@ -1,19 +1,23 @@
*
- * CHD OpenWRT is free software: you can redistribute it and/or modify
+ * CHD LEDE is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,19 +1,23 @@
* (at your option) any later version.
*
- * CHD OpenWRT is distributed in the hope that it will be useful,
+ * CHD LEDE is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the